==> jc-1.4.0.tar.gz: ppg/atoms/Nonterminal.h <==
// public class ppg.atoms.Nonterminal

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 27d4aedc7c66ddea ppg_atoms_GrammarSymbol
// @dep_class 2882cc6518b7f06 ppg_atoms_Nonterminal

// header file dependencies
// @dep_header ppg_atoms_GrammarSymbol

#include "ppg/atoms/GrammarSymbol.h"

#ifndef _JC_ppg_atoms_Nonterminal_H_
#define _JC_ppg_atoms_Nonterminal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_atoms_Nonterminal$sub_refs	_jc_ppg_atoms_Nonterminal$sub_refs;
typedef struct _jc_ppg_atoms_Nonterminal$sub_nonrefs	_jc_ppg_atoms_Nonterminal$sub_nonrefs;
typedef struct _jc_ppg_atoms_Nonterminal$refs	_jc_ppg_atoms_Nonterminal$refs;
typedef struct _jc_ppg_atoms_Nonterminal$nonrefs	_jc_ppg_atoms_Nonterminal$nonrefs;
typedef struct _jc_ppg_atoms_Nonterminal$object	_jc_ppg_atoms_Nonterminal$object;

typedef const struct _jc_ppg_atoms_Nonterminal$vmethods	_jc_ppg_atoms_Nonterminal$vmethods;
typedef const struct _jc_ppg_atoms_Nonterminal$vtable	_jc_ppg_atoms_Nonterminal$vtable;
typedef const struct _jc_ppg_atoms_Nonterminal$vtype	_jc_ppg_atoms_Nonterminal$vtype;

// Constructors
extern void _jc_ppg_atoms_Nonterminal$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *, struct _jc_java_lang_String$object *);
extern void _jc_ppg_atoms_Nonterminal$method$_init$a34354cd9552963f(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_Nonterminal$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *);
extern jboolean _jc_ppg_atoms_Nonterminal$method$equals$8a15e0625571c581(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_Nonterminal$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_Nonterminal$method_info$equals$8a15e0625571c581;

// Virtual methods structure
struct _jc_ppg_atoms_Nonterminal$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_ppg_atoms_Nonterminal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
	_jc_ppg_atoms_GrammarSymbol$vmethods	ppg_atoms_GrammarSymbol;
	_jc_ppg_atoms_Nonterminal$vmethods	ppg_atoms_Nonterminal;
};

// Vtype
struct _jc_ppg_atoms_Nonterminal$vtype {
	_jc_type			type;
	_jc_ppg_atoms_Nonterminal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_Nonterminal$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_atoms_Nonterminal$refs {
    _jc_ppg_atoms_Nonterminal$sub_refs	ppg_atoms_Nonterminal;
    _jc_ppg_atoms_GrammarSymbol$sub_refs	ppg_atoms_GrammarSymbol;
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_Nonterminal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_Nonterminal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
    _jc_ppg_atoms_GrammarSymbol$sub_nonrefs	ppg_atoms_GrammarSymbol;
    _jc_ppg_atoms_Nonterminal$sub_nonrefs	ppg_atoms_Nonterminal;
};

// Object instance structure
struct _jc_ppg_atoms_Nonterminal$object {
	_jc_ppg_atoms_Nonterminal$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_Nonterminal$vtype	*vtype;
	_jc_ppg_atoms_Nonterminal$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_Nonterminal$vtype _jc_ppg_atoms_Nonterminal$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_Nonterminal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_Nonterminal$class_object;

#endif	/* _JC_ppg_atoms_Nonterminal_H_ */

==> jc-1.4.6.tar.gz: ppg/atoms/Nonterminal.h <==
// public class ppg.atoms.Nonterminal

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ad102a5c5cfc3a0e ppg_atoms_GrammarPart
// @dep_class 27d4aedc7c66ddea ppg_atoms_GrammarSymbol
// @dep_class 2882cc6518b7f06 ppg_atoms_Nonterminal

// header file dependencies
// @dep_header ppg_atoms_GrammarSymbol

#include "ppg/atoms/GrammarSymbol.h"

#ifndef _JC_ppg_atoms_Nonterminal_H_
#define _JC_ppg_atoms_Nonterminal_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_atoms_Nonterminal$sub_refs	_jc_ppg_atoms_Nonterminal$sub_refs;
typedef struct _jc_ppg_atoms_Nonterminal$sub_nonrefs	_jc_ppg_atoms_Nonterminal$sub_nonrefs;
typedef struct _jc_ppg_atoms_Nonterminal$refs	_jc_ppg_atoms_Nonterminal$refs;
typedef struct _jc_ppg_atoms_Nonterminal$nonrefs	_jc_ppg_atoms_Nonterminal$nonrefs;
typedef struct _jc_ppg_atoms_Nonterminal$object	_jc_ppg_atoms_Nonterminal$object;

typedef const struct _jc_ppg_atoms_Nonterminal$vmethods	_jc_ppg_atoms_Nonterminal$vmethods;
typedef const struct _jc_ppg_atoms_Nonterminal$vtable	_jc_ppg_atoms_Nonterminal$vtable;
typedef const struct _jc_ppg_atoms_Nonterminal$vtype	_jc_ppg_atoms_Nonterminal$vtype;

// Constructors
extern void _jc_ppg_atoms_Nonterminal$method$_init$c31b894660454d13(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_atoms_Nonterminal$method$_init$a34354cd9552963f(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_Nonterminal$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *) _JC_JCNI_ATTR;
extern jboolean _jc_ppg_atoms_Nonterminal$method$equals$8a15e0625571c581(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_Nonterminal$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_Nonterminal$method_info$equals$8a15e0625571c581;

// Virtual methods structure
struct _jc_ppg_atoms_Nonterminal$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_ppg_atoms_Nonterminal$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_atoms_Nonterminal$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_GrammarPart$vmethods	ppg_atoms_GrammarPart;
	_jc_ppg_atoms_GrammarSymbol$vmethods	ppg_atoms_GrammarSymbol;
	_jc_ppg_atoms_Nonterminal$vmethods	ppg_atoms_Nonterminal;
};

// Vtype
struct _jc_ppg_atoms_Nonterminal$vtype {
	_jc_type			type;
	_jc_ppg_atoms_Nonterminal$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_Nonterminal$sub_refs {
};

// Reference instance fields (object)
struct _jc_ppg_atoms_Nonterminal$refs {
    _jc_ppg_atoms_Nonterminal$sub_refs	ppg_atoms_Nonterminal;
    _jc_ppg_atoms_GrammarSymbol$sub_refs	ppg_atoms_GrammarSymbol;
    _jc_ppg_atoms_GrammarPart$sub_refs	ppg_atoms_GrammarPart;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_Nonterminal$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_Nonterminal$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_GrammarPart$sub_nonrefs	ppg_atoms_GrammarPart;
    _jc_ppg_atoms_GrammarSymbol$sub_nonrefs	ppg_atoms_GrammarSymbol;
    _jc_ppg_atoms_Nonterminal$sub_nonrefs	ppg_atoms_Nonterminal;
};

// Object instance structure
struct _jc_ppg_atoms_Nonterminal$object {
	_jc_ppg_atoms_Nonterminal$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_Nonterminal$vtype	*vtype;
	_jc_ppg_atoms_Nonterminal$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_Nonterminal$vtype _jc_ppg_atoms_Nonterminal$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_Nonterminal, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_Nonterminal$class_object;

#endif	/* _JC_ppg_atoms_Nonterminal_H_ */
